from setuptools import find_namespace_packages, setup

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
]

install_requires: list = ["straight.plugin", "configtype", "Django>=5.2,<5.3"]

extras_require: dict = {
    "test": [
        "wheel",
        "empty_testproject",
        "pylint-django",
        "isort",
        "ruff",
        "vdt.versionplugin.wheel",
        "ocyan.plugin.testing",
        "coverage",
    ]
}

setup(
    name="ocyan.core",
    version="1.2.12rc1",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.core",
    author="Mandel",
    author_email="info@mandelblog.com",
    description="A framework for ocyan plugins, all plugins depend on this.",
    packages=find_namespace_packages(include=["ocyan.*"]),
    include_package_data=True,
    python_requires=">=3.10",
    install_requires=install_requires,
    classifiers=PACKAGE_CLASSIFIERS,
    extras_require=extras_require,
)
